Learn R Programming

mkde (version 0.2)

dugongdem: A RasterLayer containing bathymetry for the dugong data

Description

A 10-meter resolution bathymetric surface of the core seagrass habitat in depth below the mean sea level within the dugong's range (Sheppard et. al. 2007).

Usage

data(dugongdem)

Arguments

Format

A raster package RasterLayer object with 220 rows, 485 columns, and a cell size of 10 by 10 meters. Each cell contains a depth at low tide in meters.

References

Sheppard, J. K., Lawler, I. R., & Marsh, H. (2007). Seagrass as pasture for seacows: Landscape-level dugong habitat evaluation. Estuarine, Coastal and Shelf Science, 71(1), 117-132.

Examples

Run this code
library(raster)
data(dugongdem)
plot(dugongdem)

Run the code above in your browser using DataLab